@@ -1,9 +1,16 @@
-__all__ = ["predict", "predict_dl", "convert_raw_prediction", "convert_raw_predictions"]
+__all__ = [
+    "predict",
+    "predict_dl",
+    "convert_raw_prediction",
+    "convert_raw_predictions",
+]
 
 from icevision.imports import *
 from icevision.utils import *
 from icevision.core import *
 from icevision.models.utils import _predict_dl
+from icevision.data import *
+from icevision.models.torchvision_models.faster_rcnn.dataloaders import infer_dl
 
 
 @torch.no_grad()
