@@ -7,7 +7,7 @@ def open_img(fn, gray=False):
     if not os.path.exists(fn):
         raise ValueError(f"File {fn} does not exists")
     color = cv2.COLOR_BGR2GRAY if gray else cv2.COLOR_BGR2RGB
-    return cv2.cvtColor(cv2.imread(str(fn)), color)
+    return cv2.cvtColor(cv2.imread(str(fn), cv2.IMREAD_UNCHANGED), color)
 
 
 def show_img(img, ax=None, show: bool = False, **kwargs):
@@ -40,23 +40,38 @@ def plot_grid(fs: List[callable], ncols=1, figsize=None, show=False, **kwargs):
         plt.show()
 
 
-def plot_grid_preds_actuals(actuals, predictions, figsize=None, show=False, **kwargs):
+def plot_grid_preds_actuals(
+    actuals, predictions, figsize=None, show=False, annotations=None, **kwargs
+):
     fig, axs = plt.subplots(
         nrows=len(actuals),
         ncols=2,
-        figsize=figsize or (6 * len(actuals) / 2, 6 * len(actuals) / 2 / 0.75),
+        figsize=figsize or (6, 6 * len(actuals) / 2 / 0.75),
         **kwargs,
     )
-
+    i = 0
     for im, ax in zip(zip(actuals, predictions), axs.reshape(-1, 2)):
         ax[0].imshow(im[0], cmap=None)
-        ax[0].set_axis_off()
         ax[0].set_title("Ground truth")
-
         ax[1].imshow(im[1], cmap=None)
-        ax[1].set_axis_off()
         ax[1].set_title("Prediction")
 
+        if annotations is None:
+            ax[0].set_axis_off()
+            ax[1].set_axis_off()
+        else:
+            ax[0].get_xaxis().set_ticks([])
+            ax[0].set_frame_on(False)
+            ax[0].get_yaxis().set_visible(False)
+            ax[0].set_xlabel(annotations[i][0], ma="left")
+
+            ax[1].get_xaxis().set_ticks([])
+            ax[1].set_frame_on(False)
+            ax[1].get_yaxis().set_visible(False)
+            ax[1].set_xlabel(annotations[i][1], ma="left")
+
+            i += 1
+
     plt.tight_layout()
     if show:
         plt.show()
